@@ -1,6 +1,7 @@
 import os
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Callable, Tuple
+from idom.core.proto import VdomDict
 
 import markdown
 import idom
@@ -10,13 +11,31 @@ from idom.utils import html_to_vdom
 HERE = Path(__file__).parent
 
 
-def use_slides(path_to_markdown_slides):
+def use_slides(
+    path_to_markdown_slides, initial_slide_index: int
+) -> Tuple[List[VdomDict], Callable[[int], None]]:
     slides_path = Path(path_to_markdown_slides)
     project_path = Path(path_to_markdown_slides).parent
-    return idom.hooks.use_memo(
-        lambda: load_slides(project_path, slides_path), args=[project_path, slides_path]
+
+    all_slides = idom.hooks.use_memo(
+        lambda: load_slides(project_path, slides_path),
+        args=[project_path, slides_path],
     )
 
+    visible_slide_index, set_visible_slide_index = idom.hooks.use_state(
+        initial_slide_index
+    )
+
+    for index, slide in enumerate(all_slides):
+        slide_attrs = slide["attributes"]
+        if index == visible_slide_index:
+            slide_attrs["id"] = "slide"
+        else:
+            slide_attrs.pop("id", None)
+            slide_attrs["style"]["display"] = "none"
+
+    return all_slides, visible_slide_index, set_visible_slide_index
+
 
 def load_slides(project_path, slides_path):
     with open(slides_path, "r") as f:
@@ -51,7 +70,10 @@ def markdown_to_slidedeck(project_path: Path, md: str) -> List[Dict[str, Any]]:
     slides = []
     for j in range(len(slide_boundaries) - 1):
         start, stop = slide_boundaries[j : j + 2]
-        slides.append((header, *nodes[start:stop]))
+        slide_element = idom.html.div(
+            {"style": {"display": "block"}}, header, *nodes[start:stop]
+        )
+        slides.append(slide_element)
 
     return slides
 
